%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Neoclassical growth model in continuos time                    %
% solved by HJB equation (ODE)                                   %
%                                                                %
% by Ivan Werning, 2003                                          %
% remark: requires dV.m file                                     %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% housekeeping
clear
global alpha delta rho sigma kss

% parameter values
alpha = .33;
delta = 0.1;
rho  = .03;
sigma =  .5;

% SS values
kss     = ((rho + delta)/alpha)^(-1/(1 - alpha)); % compute steady state
css     = kss^alpha; % steady state consumption
kgr     = ((delta)/alpha)^(-1/(1 - alpha)); % compute golden rule capital
vss     = u(css)/rho;

% solve ODE using the SS as a boundary condition
[K, V] = ode45('dV',[kss kss*.5],[vss],odeset('reltol',1e-20,'abstol',1e-40))
%figure(1); plot(K,V); grid

% compute derivative
for i=1:length(K)
    Vprime(i) = dV(K(i),V(i));
end

% plot dv
figure(2); plot(K,Vprime);grid
