%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% plots the evolution of (c,k) for the
% continuous time neoclassical growth model
% using the EE and resource constraint for a given k0
% and a guess for c0 (the c0 that leads to the SS is NOT 
%
% by Ivan Werning, 2003
% remark: good to run after running phase.m with same parameters
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% note: you can run phase.m first and then this program to get a 
% nicer figure; but make sure you have the same parameters 
% in both programs

global alpha sigma rho delta
hold on

% parameters
rho   = .02;
delta = .1;
alpha = .5;
sigma = .5;

tf=400; % time lenght to compute path on

kss= ((rho+delta)/alpha)^(1/(alpha-1));
css = kss^alpha - delta*kss;

% options for ode (output here is phase diagram)
odeoptions = odeset('outputf','odephas2','Abst',1e-20);

% initial condition for k and initial guess for consumption
% note: c0=.5*css works very well for the default parameters
% [rho   = .02; delta = .1; alpha = .5; sigma = .5;]
% but try other parameters for fun...
k0 = .5*kss
c0 = .6*css;

% compute ODE (Ordinary Differential Equation system)
[T X]=ode45('rck',[0,tf],[ k0 , c0 ]);

% plot result
hold on
plot(X(:,1),X(:,2))

% of couse we could create a shooting algorithm with this code
% much like we did for the discrete time case...
% ...this is a good exercise