%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% produces phase diagram for the neoclassical growth model       %
% in continous time                                              %
%                                                                %
% by Ivan Werning, 2003                                          %
%                                                                %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% parameters
rho   = .02;
delta = .1;
alpha = .5;
sigma = .5;

% steady state etc... values
kss     = ((rho + delta)/alpha)^(-1/(1 - alpha))
css     = kss^alpha - delta*kss; % steady state consumption
kgr     = (delta/alpha)^(-1/(1 - alpha))
kmax    = (delta)^(1/(alpha-1))
ratio   = kmax/kss
ratio2  = kgr/kmax
ratio2b = alpha^(1/(1-alpha))

% boundaries for grids
khigh  = kgr;
klow   = kss*.1;
chigh  = css*1.3;
clow   = css*.01;
nc =  25;
nk =  25;

% compute field
[K C]=meshgrid((klow:(khigh-klow)/(nk-1):khigh),(clow:(chigh-clow)/(nc-1):chigh));
dk = K.^alpha - delta*K - C;
dc = [alpha*K.^(alpha-1) - delta - rho]/sigma;

% plot field
quiver(K,C,dk,dc,.75,'r')


Nc = 100; klow = kss*.001;
Nk = 100;
[KK CC]=meshgrid((klow:(khigh-klow)/(Nk-1):khigh),(clow:(chigh-clow)/(Nc-1):chigh));
dkk = KK.^alpha - delta*KK - CC;
dcc = alpha*KK.^(alpha-1) - delta - rho;

hold on
contour(KK,CC,dkk,[0 0],'b')
contour(KK,CC,dcc,[0 0],'b')
hold off

axis([klow, khigh, clow, chigh]);