%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Neoclassical growth model discrete time                                       %
% solved by shooting algorithm using discrete time Euler                        %
% equation Neoclassical growth model                                            %
%                                                                               %
% note: instead of checking transversality conditions I check the distance from %
% the SS capital level (since we know we should converge there and that this is %
% the only path that will satisfy the EE and TC anyway)                         %
%                                                                               %
% by Ivan Werning                                                               %
%                                                                               %
% remark: requires f.m                                                          %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


% housekeeping
clear
global alpha delta beta sigma CARA

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% parameter values
alpha = .33;
delta = .1;
rho  =.03;
beta  = 1/(1+rho);
sigma =  1;
CARA  =  1;
gridn   = 1000;
klow    = .5; khigh =1;
T       = 200;

% create grid for capital
kss     = ((1/beta - 1 + delta)/alpha)^(-1/(1 - alpha)); % compute steady state
css     = f(kss) - kss; % steady state consumption
kgr     = ((delta)/alpha)^(-1/(1 - alpha)); % compute golden rule capital


% initialize
k(1)    = kss*.5 
upper = f(k(1));
lower = 0.0001*css;
i=0; crit = 1;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% iterate interpolating values until either k converges to kss and c to css
% or upper and lower ar very close or after enough iterations
% note: you are warned that if you get too ambitious about the precision
% you want you may hit the precision constraint on Matlab
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
while crit >1e-6 & i < 100 & upper-lower>1e-20
    
    % update initial consumption
    c(1) = (upper + lower)/2;
    
    for t=1:T-1    
        
        if f(k(t)) - c(t) <= 0
            k(t+1)=0;
            c(t+1)=0;
            'we hit k=0'
        else
            k(t+1) = f(k(t)) - c(t);
            MgPk   = alpha*k(t+1)^(alpha-1) + 1 - delta;
            c(t+1) = c(t)*(MgPk)^(1/sigma);
        end
        
    end
    clc    
    crit = max (abs(c(T)-css)/css, abs(k(T)-kss)/kss)
    i=i+1
    
    if k(T) > kss
        lower = c(1)
    else
        upper = c(1)
    end
    upper-lower
end

plot(k,c); grid
